@@ -243,8 +243,12 @@ class MarketAnalyzer:
                 # print(p)
 
             for a in self.assets:
-                results[i, j] = f((getattr(self.df, a).values), **p)
-                j += 1
+                try:
+                    results[i, j] = f((getattr(self.df, a).values), **p)
+                    j += 1
+                except Exception as inst:
+                    print(inst)
+                    continue
 
             i += 1
 
