@@ -26,13 +26,14 @@ def unjsonize_mapping_dataframe(mapping_df):
 
 class ParallelRunResultAnalyzer():
 
-    def __init__(self,drop_token='', dropbox_backup=True, local_root_directory='../data',user='napoleon',  db_path_suffix = '_run.sqlite'):
+    def __init__(self,drop_token='', dropbox_backup=True, local_root_directory='../data',user='napoleon',  db_path_suffix = '_run.sqlite', max_table_number = 20):
         self.local_root_directory = local_root_directory
         self.user = user
         self.db_path_suffix = db_path_suffix
         self.filename =  user + db_path_suffix
         self.db_path = self.local_root_directory + self.filename
         self.dbx = dropbox_file_saver.NaPoleonDropboxConnector(drop_token=drop_token,dropbox_backup=dropbox_backup)
+        self.max_table_number = max_table_number
 
     def getAllRuns(self):
         sqliteConnection = None
@@ -81,14 +82,15 @@ class ParallelRunResultAnalyzer():
         signals_df = self.analyzeAllRunSignalsResults(jsonized_output=jsonized_output)
         return results_df, signals_df
 
-    def analyzeAllRunSignalsResults(self,jsonized_output = True):
+    def analyzeLocalAllRunSignalsResults(self,table_number, jsonized_output = True):
         sqliteConnection = None
         try:
             sqliteConnection = sqlite3.connect(self.db_path, timeout=20)
-            sqlite_select_run_query = """SELECT * from parallel_signal order by effective_date asc"""
+            sqlite_select_run_query = """SELECT * from parallel_signal_"""+str(table_number)+""" order by effective_date asc"""
             results_df = pd.read_sql_query(sqlite_select_run_query, sqliteConnection)
-        except sqlite3.Error as error:
+        except Exception as error:
             print("Failed to read data from sqlite table", error)
+            return None
         finally:
             if (sqliteConnection):
                 sqliteConnection.close()
@@ -126,14 +128,43 @@ class ParallelRunResultAnalyzer():
             results_df = results_df.rename(columns=renaming_dictionary, errors="raise")
         return results_df
 
+    def analyzeAllRunSignalsResults(self,jsonized_output = True):
+        results_df = None
+        for table_number in range(self.max_table_number):
+            local_df = self.analyzeLocalAllRunSignalsResults(table_number,jsonized_output)
+            if local_df is not None:
+                if results_df is None:
+                    results_df = local_df.copy()
+                else:
+                    print('merging table ' + str(local_df.shape))
+                    results_df = pd.merge(results_df, local_df, how='left', on=['Date'])
+            else :
+                break
+        return results_df
+
     def analyzeAllRunPerfResults(self,jsonized_output = True):
+        results_df = None
+        for table_number in range(self.max_table_number):
+            local_df = self.analyzeLocalAllRunPerfResults(table_number,jsonized_output)
+            if local_df is not None:
+                if results_df is None:
+                    results_df = local_df.copy()
+                else:
+                    print('merging table ' + str(local_df.shape))
+                    results_df = pd.merge(results_df, local_df, how='left', on=['Date'])
+            else :
+                break
+        return results_df
+
+    def analyzeLocalAllRunPerfResults(self,table_number, jsonized_output = True):
         sqliteConnection = None
         try:
             sqliteConnection = sqlite3.connect(self.db_path, timeout=20)
-            sqlite_select_run_query = """SELECT * from parallel_run order by effective_date asc"""
+            sqlite_select_run_query = """SELECT * from parallel_run_"""+str(table_number)+""" order by effective_date asc"""
             results_df = pd.read_sql_query(sqlite_select_run_query, sqliteConnection)
-        except sqlite3.Error as error:
+        except Exception as error:
             print("Failed to read data from sqlite table", error)
+            return None
         finally:
             if (sqliteConnection):
                 sqliteConnection.close()
